@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BasicFileWriter.h 2035 2006-11-23 16:14:21Z svn $
+ * $Id: BasicFileWriter.h 2162 2006-12-03 14:36:10Z svn $
  *****************************************************************************/
 
 #ifndef BASIC_FILE_WRITER_H
@@ -44,7 +44,7 @@ using namespace std;
 class BasicFileWriter: public FileWriter
 {
 public:
-    static const apr_int32_t OPEN_FLAG;
+    static const apr_int32_t OPEN_FLAG  = APR_READ|APR_WRITE|APR_BINARY|APR_BUFFERED;
     /**
      * コンストラクタ．
      *
@@ -54,8 +54,6 @@ public:
      * @param[in] file ファイルハンドラ
      * @param[in] offset 書き出しを開始する位置
      */
-
-public:
     BasicFileWriter(apr_pool_t *pool, apr_file_t *file, apr_size_t offset=0);
     /**
      * ファイルへの書き出しを行います．
