@@ -1,7 +1,5 @@
 /******************************************************************************
- * mod_uploader / ConfigReader.h
- ******************************************************************************
- * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
+ * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
  *
  * All rights reserved.
  *
@@ -24,57 +22,48 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ConfigReader.h 1003 2006-03-14 13:52:47Z svn $
+ * $Id: ConfigReader.h 2085 2006-11-25 19:29:52Z svn $
  *****************************************************************************/
 
 #ifndef CONFIG_READER_H
 #define CONFIG_READER_H
 
-#include "apr_pools.h"
+#include "Environment.h"
 
-#include <string>
-#include <map>
+#include <cstdlib>
 
-#ifdef HAVE_CONFIG_H
-#include "mod_uploader_config.h"
-#endif
+#include "apr_tables.h"
+
+#include "Uncopyable.h"
 
 using namespace std;
 
 /**
- * @brief եɤ߹९饹
+ * @brief 設定ファイルを読み込むクラス．
  */
-class ConfigReader
+class ConfigReader: public Uncopyable
 {
 public:
-    typedef map<string, string> config_map; // multimap ǤϤʤ
-    typedef pair<string, string> config_pair;
-
-    static config_map *read(apr_pool_t *pool, const char *file_path);
+    static apr_table_t *read(apr_pool_t *pool, const char *conf_file_path);
 
 private:
     static const char COMMENT_CHAR;
     static const char QUOTE_CHAR;
     static const char ASSIGN_CHAR;
 
-    static void read_file(apr_pool_t *pool, const char *file_path,
-                          const char **data);
-    static void read_line(apr_pool_t *pool, const char **data,
+    static bool read_line(apr_pool_t *pool, const char **input,
                           const char **name, const char **value);
-    static void read_param(apr_pool_t *pool, const char **data,
+    static void read_param(apr_pool_t *pool, const char **input,
                            const char **name, const char **value);
-    static void read_word(apr_pool_t *pool, const char **data,
+    static void read_word(apr_pool_t *pool, const char **input,
                           const char **word);
-    static void skip_space(const char **data);
-    static void skip_line(const char **data);
-
-    ConfigReader(const ConfigReader&);
-    ConfigReader &operator=(const ConfigReader&);
+    static void skip_space(const char **input);
+    static void skip_line(const char **input);
 };
 
 #endif
 
 // Local Variables:
 // mode: c++
-// buffer-file-coding-system: euc-japan-dos
+// coding: utf-8-dos
 // End:
