@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostDataChecker.h 2271 2006-12-16 20:15:22Z svn $
+ * $Id: PostDataChecker.h 2272 2006-12-17 10:21:48Z svn $
  *****************************************************************************/
 
 #ifndef POST_DATA_CHECKER_H
@@ -45,7 +45,7 @@ using namespace std;
 class PostDataChecker: public Uncopyable
 {
 public:
-    static void validate_uitem(apr_pool_t *pool, apr_off_t file_size,
+    static void validate_uitem(apr_pool_t *pool, apr_uint64_t file_size,
                                apr_time_t  mtime, const char **file_name,
                                const char **file_mime, const char *file_digest,
                                const char *remove_pass,
