@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateExecutor.cpp 2144 2006-11-29 14:54:20Z svn $
+ * $Id: TemplateExecutor.cpp 2175 2006-12-06 17:27:48Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -39,7 +39,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 2144 2006-11-29 14:54:20Z svn $");
+SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 2175 2006-12-06 17:27:48Z svn $");
 #endif
 
 #ifdef DEBUG_TemplateExecutor
@@ -698,6 +698,7 @@ TEMPLATE_EXECUTOR_INLINE void TemplateExecutor<W>::print(int i) throw()
 typedef TemplateExecutor<CGIResponseWriter> TemplateExecutorImpl;
 
 static const apr_size_t ITEM_LIST_SIZE  = 10;
+static const apr_uint64_t MAX_FILE_SIZE = 1000000;
 static const apr_size_t MAX_LIST_SIZE   = 1000;
 
 void show_usage(const char *prog_name)
@@ -767,8 +768,9 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
 
     thumbnail_list = ThumbnailList::get_instance(thumbnail_list_shm,
                                                  MAX_LIST_SIZE);
-    item_list = UploadItemListReader::read(pool, data_dir_path, item_list_shm,
-                                           thumbnail_list, MAX_LIST_SIZE);
+    item_list = UploadItemListReader::read(pool, data_dir_path, data_dir_path,
+                                           item_list_shm, thumbnail_list,
+                                           MAX_FILE_SIZE, MAX_LIST_SIZE);
 
     show_item("data dir", data_dir_path);
     show_item("template file", tmpl_file_path);
