@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.cpp 2271 2006-12-16 20:15:22Z svn $
+ * $Id: UploadItem.cpp 2272 2006-12-17 10:21:48Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -40,7 +40,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItem.cpp 2271 2006-12-16 20:15:22Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItem.cpp 2272 2006-12-17 10:21:48Z svn $");
 
 #define AS_BCOMMENT(pointer)        reinterpret_cast<bbs_comment_t *>(pointer)
 #define UINT16(pointer)             static_cast<apr_uint16_t>(pointer)
@@ -55,7 +55,7 @@ UploadItem::UploadItem()
 
 UploadItem *UploadItem::get_instance(void *memory, apr_size_t item_id,
                                      apr_size_t item_index,
-                                     apr_off_t file_size, apr_time_t mtime,
+                                     apr_uint64_t file_size, apr_time_t mtime,
                                      const char *ip_address,
                                      const char *file_name,
                                      const char *file_mime,
@@ -102,7 +102,7 @@ UploadItem *UploadItem::get_instance(void *memory, apr_size_t item_id,
 
 UploadItem *UploadItem::get_instance(apr_pool_t *pool, apr_size_t item_id,
                                      apr_size_t item_index,
-                                     apr_off_t file_size, apr_time_t mtime,
+                                     apr_uint64_t file_size, apr_time_t mtime,
                                      const char *ip_address,
                                      const char *file_name,
                                      const char *file_mime,
