@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.cpp 2173 2006-12-06 16:12:56Z svn $
+ * $Id: UploadItemManager.cpp 2273 2006-12-17 13:35:43Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -47,7 +47,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2173 2006-12-06 16:12:56Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2273 2006-12-17 13:35:43Z svn $");
 
 #ifdef DEBUG
 #include <iostream>
@@ -83,7 +83,7 @@ void UploadItemManager::init(UploadItemList *item_list,
 
 apr_size_t UploadItemManager::add(apr_pool_t *pool,
                                   const char *file_name, const char *file_mime,
-                                  apr_off_t file_size, const char *file_digest,
+                                  apr_uint64_t file_size, const char *file_digest,
                                   const char *file_temp_path,
                                   const char *remove_pass,
                                   const char *download_pass,
@@ -167,7 +167,8 @@ UploadItem *UploadItemManager::get_item(apr_pool_t *pool, apr_size_t item_id)
 }
 
 apr_file_t *UploadItemManager::get_item_file(apr_pool_t *pool,
-                                             apr_size_t item_id)
+                                             apr_size_t item_id,
+                                             bool is_sendfile_enabled)
 {
     const char *file_path;
     apr_file_t *file;
@@ -183,7 +184,8 @@ apr_file_t *UploadItemManager::get_item_file(apr_pool_t *pool,
 
     uitem->increment_download_count();
 
-    apr_file_open(&file, file_path, APR_READ|APR_SENDFILE_ENABLED,
+    apr_file_open(&file, file_path,
+                  APR_READ | (is_sendfile_enabled ? APR_SENDFILE_ENABLED : 0),
                   APR_OS_DEFAULT, pool);
 
     return file;
