@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemVariableCreator.cpp 2279 2006-12-17 19:59:56Z svn $
+ * $Id: UploadItemVariableCreator.cpp 2283 2006-12-20 15:19:04Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -32,7 +32,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemVariableCreator.cpp 2279 2006-12-17 19:59:56Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemVariableCreator.cpp 2283 2006-12-20 15:19:04Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -155,6 +155,11 @@ UploadItemVariableCreator::create_item(apr_pool_t *pool, UploadItem *uitem,
     sca->s      = uitem->get_date();
     sca->l      = 0;
 
+    sca         = item_sca + item_index_.ip_address.index;
+    sca->type   = TemplateVariable::STRING;
+    sca->s      = uitem->get_ip_address();
+    sca->l      = 0;
+
     sca         = item_sca + item_index_.file_name.index;
     sca->type   = TemplateVariable::STRING;
     sca->s      = uitem->get_file_name();
